@@ -436,23 +436,28 @@ def get_scope_of_host_ids_from_host_list():
     return host_list_records, host_list_records_count, host_list_get_scope_of_host_ids_sql
 
 
-def start_msg_get_host_list_detection_data():
+def end_message_info():
+    etld_lib_functions.logger.info(f"host_list sqlite file: {etld_lib_config.host_list_sqlite_file}")
+
+
+def begin_host_list_detection_03_extract_controller():
     etld_lib_functions.logger.info(f"start")
 
 
-def end_msg_get_host_list_detection_data(host_list_records, host_list_get_scope_of_host_ids_sql):
-    etld_lib_functions.logger.info(f"host_list get_scope_of_host_ids sql: {host_list_get_scope_of_host_ids_sql}")
-    etld_lib_functions.logger.info(f"host_list sqlite file: {etld_lib_config.host_list_sqlite_file}")
-    etld_lib_functions.logger.info(f"count host_list where last_vuln_scan_datetime is not blank or null: {len(host_list_records):,}")
+def end_host_list_detection_03_extract_controller():
+    end_message_info()
     etld_lib_functions.logger.info(f"end")
 
 
 def extract_host_list_detection_via_multiprocessing_manager():
-    start_msg_get_host_list_detection_data()
     etld_lib_config.remove_old_files(
         dir_path=etld_lib_config.host_list_detection_extract_dir,
         dir_search_glob=etld_lib_config.host_list_detection_extract_dir_file_search_blob,
         other_files_list=etld_lib_config.host_list_detection_data_files)
+    etld_lib_config.remove_old_files(
+        dir_path=etld_lib_config.host_list_detection_distribution_dir,
+        dir_search_glob=etld_lib_config.host_list_detection_distribution_dir_file_search_blob
+    )
 
     with multiprocessing.Manager() as manager:
 
@@ -482,12 +487,11 @@ def extract_host_list_detection_via_multiprocessing_manager():
             xml_file_paths_multiprocessing_queue=xml_file_paths_multiprocessing_queue,
             cred_dict=cred_dict)
 
-    end_msg_get_host_list_detection_data(host_list_records=host_list_records,
-                                         host_list_get_scope_of_host_ids_sql=host_list_get_scope_of_host_ids_sql)
-
 
 def main():
+    begin_host_list_detection_03_extract_controller()
     extract_host_list_detection_via_multiprocessing_manager()
+    end_host_list_detection_03_extract_controller()
 
 
 if __name__ == "__main__":
