@@ -469,20 +469,30 @@ def help_message(notes):
                                Example:
                                {{"q_username": "your userid", "q_password": "your password", "q_api_fqdn_server": "api fqdn", "q_gateway_fqdn_server": "gateway api fqdn"}}
       
-    Example: 
+    Example: ETL Host List Detection
     
     qetl_manage_user -u [path] -e etl_host_list_detection -d 1970-01-01T00:00:00Z
-
+    
+     - qetl_manage_user will download all knowledgebase, host list and host list detection vulnerability data,
+       transforming/loading it into sqlite and optionally the corresponding distribution directory.
+     
      Inputs: 
        - KnowledgeBase API, Host List API, Host List Detection API.
-     Outputs:
-       - XML, JSON, SQLITE, AND Distribution_Directory of CSV BATCH FILES PREPARED FOR DATABASE INGESTION.
        - ETL KnowledgeBase
          - /api/2.0/fo/knowledge_base/vuln/?action=list
        - ETL Host List
          - /api/2.0/fo/asset/host/?action=list
        - ETL Host List Detection - Stream of batches immediately ready for downstream database ingestion.
          - /api/2.0/fo/asset/host/vm/detection/?action=list
+     Outputs:
+       - XML, JSON, SQLITE, AND Distribution_Directory of CSV BATCH FILES PREPARED FOR DATABASE INGESTION.
+         - host_list_detection_extract_dir - contains native xml and json transform of data from qualys, compressed in uniquely named batches.
+         - host_list_detection_distribution_dir - contains transformed/prepared data ready for use in database loaders such as mysql.
+         - host_list_detection_sqlite.db - sqlite database will contain multiple tables:
+           - Q_Host_List                            - Host List Asset Data from Host List API.
+           - Q_Host_List_Detection_Hosts            - Host List Asset Data from Host List Detection API. 
+           - Q_Host_List_Detection_QIDS             - Host List Vulnerability Data from Host List Detection API. 
+           - Q_KnowledgeBase_In_Host_List_Detection - KnowledgeBase QIDs found in Q_Host_List_Detection_QIDS. 
          
    etld_config_settings.yaml notes:
        1. To Enable CSV Distribution, add the following keys to etld_config_settings.yaml and toggle on/off them via True or False
